"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const generateUrl_1 = __importDefault(require("./generateUrl"));
describe('generateUrl', () => {
    describe('no path or query string', () => {
        it('should generate URL with no dynamic path params or query string', () => {
            const result = generateUrl_1.default('/app/login', {});
            expect(result).toBe('/app/login');
        });
    });
    describe('path - strings', () => {
        it('should generate URL with required path param', () => {
            const result = generateUrl_1.default('/app/users/:id', { id: 'onehundo' });
            expect(result).toBe('/app/users/onehundo');
        });
        it('should throw error if path param is required but not in path object', () => {
            expect(() => generateUrl_1.default('/app/users/:id', {})).toThrowError('Expected "id" to be a string');
            expect(() => generateUrl_1.default('/app/users/:id', { name: 'Hundo' })).toThrowError('Expected "id" to be a string');
        });
        it('should generate URL if path param is not required and not in path object', () => {
            const result = generateUrl_1.default('/app/users/:id?', {});
            expect(result).toBe('/app/users');
        });
        it('should generate URL if path param is not required but path is in path object', () => {
            const result = generateUrl_1.default('/app/users/:id?', { id: 'onehundo' });
            expect(result).toBe('/app/users/onehundo');
        });
        it('should generate URL with required path param', () => {
            const result = generateUrl_1.default('/app/users/:id', { id: 'onehundo' });
            expect(result).toBe('/app/users/onehundo');
        });
        it('should throw error if path param is required but not in path object', () => {
            expect(() => generateUrl_1.default('/app/users/:id', {})).toThrowError('Expected "id" to be a string');
            expect(() => generateUrl_1.default('/app/users/:id', { name: 'Hundo' })).toThrowError('Expected "id" to be a string');
        });
        it('should generate URL if path param is not required and not in path object', () => {
            const result = generateUrl_1.default('/app/users/:id?', {});
            expect(result).toBe('/app/users');
        });
        it('should generate URL if path param is not required but path is in path object', () => {
            const result = generateUrl_1.default('/app/users/:id?', { id: 'onehundo' });
            expect(result).toBe('/app/users/onehundo');
        });
    });
    describe('paths - enums', () => {
        it('should generate URL with required enum path param', () => {
            const result = generateUrl_1.default('/app/users/:subview(profile|pictures)', { subview: 'profile' });
            expect(result).toBe('/app/users/profile');
        });
        it('should throw error with required enum path param and path is not in path object', () => {
            expect(() => generateUrl_1.default('/app/users/:subview(profile|pictures)', { house: 'profile' })).toThrowError('Expected "subview" to be a string');
        });
        it('should throw error with required enum path param and path is not part of enums', () => {
            expect(() => generateUrl_1.default('/app/users/:subview(profile|pictures)', { subview: 'dog' })).toThrowError('Expected "subview" to match "profile|pictures", but got "dog"');
        });
        it('should generate URL with optional enum path param and path not in path object', () => {
            const result = generateUrl_1.default('/app/users/:subview(profile|pictures)?', {});
            expect(result).toBe('/app/users');
        });
        it('should generate URL with optional enum path param and path in path object', () => {
            const result = generateUrl_1.default('/app/users/:subview(profile|pictures)?', { subview: 'profile' });
            expect(result).toBe('/app/users/profile');
        });
        it('should generate URL with optional enum path param and path is not in path object', () => {
            const result = generateUrl_1.default('/app/users/:subview(profile|pictures)?', { house: 'profile' });
            expect(result).toBe('/app/users');
        });
        it('should throw error with optional enum path param and path is not part of enums', () => {
            expect(() => generateUrl_1.default('/app/users/:subview(profile|pictures)?', { subview: 'dog' })).toThrowError('Expected "subview" to match "profile|pictures", but got "dog"');
        });
    });
    describe('query strings', () => {
        it('should generate one query string correctly', () => {
            const result = generateUrl_1.default('/app/users/:id', { id: 'oneHundo' }, { from: 'homepage' });
            expect(result).toBe('/app/users/oneHundo?from=homepage');
        });
        it('should generate multiple query strings correctly', () => {
            const result = generateUrl_1.default('/app/users/:id', { id: 'oneHundo' }, { from: 'homepage', redirect: '/login' });
            expect(result).toBe('/app/users/oneHundo?from=homepage&redirect=/login');
        });
    });
});
//# sourceMappingURL=generateUrl.test.js.map